@@ -2,13 +2,13 @@ import json
 from ast import Or
 from collections import OrderedDict
 from pathlib import Path
-from typing import Any, Iterable, Literal, Mapping, NamedTuple, Optional, Sequence, Union
+from typing import Any, Iterable, List, Mapping, NamedTuple, Optional, Sequence, Union
 
 from attrs import define
 
 from countergen.config import VERBOSE
-from countergen.converter_loading import SimpleConverter
-from countergen.types import AugmentedSample, Category, Converter, Input, Output, Variation
+from countergen.augmenter_loading import SimpleAugmenter
+from countergen.types import AugmentedSample, Category, Augmenter, Input, Output, Variation
 from countergen.utils import MODULE_PATH, maybe_tqdm
 
 default_dataset_paths: Mapping[str, str] = {"doublebind": f"{MODULE_PATH}/data/examples/doublebind.jsonl"}
@@ -17,10 +17,10 @@ default_dataset_paths: Mapping[str, str] = {"doublebind": f"{MODULE_PATH}/data/e
 def augment_dataset(
     dataset_path: str,
     save_path: str = ".",
-    converters: Iterable[Union[str, Converter]] = ["gender"],
+    augmenters: Iterable[Union[str, Augmenter]] = ["gender"],
 ):
     converters_ = [
-        SimpleConverter.from_default(converter) if isinstance(converter, str) else converter for converter in converters
+        SimpleAugmenter.from_default(converter) if isinstance(converter, str) else converter for converter in augmenters
     ]
     ds = Dataset.from_jsonl(dataset_path)
     aug_ds = generate_all_variations(converters_, ds)
@@ -40,7 +40,7 @@ class Sample:
 
 @define
 class SampleWithVariations(Sample, AugmentedSample):
-    variations: list[Variation] = []
+    variations: List[Variation] = []
 
     def get_variations(self) -> Sequence[Variation]:
         return self.variations
@@ -49,7 +49,7 @@ class SampleWithVariations(Sample, AugmentedSample):
         return self.expected_output
 
     @classmethod
-    def from_sample(cls, s: Sample, variations: list[Variation] = []):
+    def from_sample(cls, s: Sample, variations: List[Variation] = []):
         return SampleWithVariations(s.input, s.expected_output, variations)
 
     @classmethod
@@ -67,7 +67,7 @@ class SampleWithVariations(Sample, AugmentedSample):
 
 @define
 class Dataset:
-    samples: list[Sample]
+    samples: List[Sample]
 
     @classmethod
     def from_default(cls, name: str = "doublebind"):
@@ -85,7 +85,7 @@ class Dataset:
 
 @define
 class AugmentedDataset:
-    samples: list[SampleWithVariations]
+    samples: List[SampleWithVariations]
 
     def save_to_jsonl(self, path: str):
         with Path(path).open("w", encoding="utf-8") as f:
@@ -103,7 +103,7 @@ class AugmentedDataset:
         return AugmentedDataset(samples)
 
 
-def generate_variations_pair(converter: Converter, ds: Dataset) -> AugmentedDataset:
+def generate_variations_pair(converter: Augmenter, ds: Dataset) -> AugmentedDataset:
     augmented_samples = []
     for sample in maybe_tqdm(ds.samples, VERBOSE >= 2):
         variations = [
@@ -113,11 +113,11 @@ def generate_variations_pair(converter: Converter, ds: Dataset) -> AugmentedData
     return AugmentedDataset(augmented_samples)
 
 
-def generate_all_variations(converters: Iterable[Converter], ds: Dataset) -> AugmentedDataset:
+def generate_all_variations(augmenters: Iterable[Augmenter], ds: Dataset) -> AugmentedDataset:
     augmented_samples = []
     for sample in maybe_tqdm(ds.samples, VERBOSE >= 2):
         variations = [Variation(sample.input, ())]
-        for converter in converters:
+        for converter in augmenters:
             new_variations = []
             for category in converter.categories:
                 new_variations += [
